%  AverageSpectrum(timeSeries, fsamp, numWindows, window) produces a properly
%  normalized power spectrum , P(f), of timeSeries, sampled at fsamp, using the
%  window function given by the user, and averaged over numWindows of windows.
%  The resulting spectrum is plotted on a loglog axis.

%  Jeffrey Moffitt
%  November 15, 2004

function [spectrum,spectrumraw, f] = AverageSpectrum(timeSeries, fsamp, numWindows, window)

%default parameter values
if nargin < 4; window = @nowindow; end;
if nargin < 3; numWindows = 1; window = @nowindow; end;

index1 = 1;
index2 = floor(length(timeSeries)/numWindows);
[sumSpectrum, f] = OneSidedSpectrum(timeSeries(index1:index2), fsamp, window);
[r c] = size(sumSpectrum);
tempSpectrum = zeros(numWindows,c);
tempSpectrum(1,:) = sumSpectrum;
for i = 2:numWindows
    index1 = floor(length(timeSeries)/numWindows)*(i-1)+1;
    index2 = floor(length(timeSeries)/numWindows)*i;
    tempSpectrum(i,:) = OneSidedSpectrum(timeSeries(index1:index2), fsamp, window);
end
sumSpectrum = sum(tempSpectrum);
spectrum = sumSpectrum/numWindows;

spectrumraw = spectrum;

end


