function spectrum2 = rem_spec_resonance(f,spectrum,n,thresh)
%A decent method of removing resonances from a bead power spectrum for
%fitting purposes. Fits a polynomial of order n to spectrum to use as a
%baseline for finding resonances and replacing spectrum values.

%140502 mjc

%fit a polymer to subtract the base spectrum
pspec = polyfit(f,spectrum,n);%6th order
spec_pfit = polyval(pspec,f);
r = log(spectrum./spec_pfit);
%thresh = 0.5;%seems good
outliers = r > thresh;

spectrum2 = spectrum;
spectrum2(outliers) = spec_pfit(outliers);%replace outlier values with the fit values

global rem_out_diag
if isempty(rem_out_diag)
    rem_out_diag = 0;
end
if rem_out_diag
    hfig = figure;
    subplot(2,1,1)
    loglog(f,spectrum);
    hold on
    loglog(f,spectrum2,'k');
    loglog(f,spec_pfit,'r');
    title('Removal of resonances from spectrum')
    legend({'Raw spectrum' 'Smoothed spectrum' 'Raw spectrum poly fit'})
    
    subplot(2,1,2)
    semilogx(f,r)
    flim = [f(2) f(end)];
    hold on
    semilogx(flim,[1 1]*thresh,'r:');
    xlabel('Frequency (Hz)')
    legend({'Log(spectrum/spectrum\_fit)' 'Removal threshold'})
    title('Criteria for removing outlier resonances')
end

end
