function hist_open_close_cb(arg1,arg2)
%Working from the global f-ext analysis list, create a histogram of the
%forces for opening tether during pulls

global f_ext_analysis_global_list;

xy = f_ext_analysis_global_list;

%xy entries 1 and 2 are first point (in time) (ext,F), entries 4 and 5 are
%second point (in time) (ext,F). 

%compute change in extension for each event (then know open/close)

delta_ext = xy(:,4) - xy(:,1);% >0 is open, <0 is close

%make a list of pulls and relaxations

even_odd = mod(xy(:,7),2);

i_pulls_open = find(even_odd == 1 & delta_ext > 0);
i_pulls_close = find(even_odd == 1 & delta_ext < 0);

i_relaxes_open = find(even_odd == 0 & delta_ext > 0);
i_relaxes_closed = find(even_odd == 0 & delta_ext < 0);

figure

subplot(2,1,1)
hist(xy(i_pulls_open,2))
a1 = gca;
title({'Tether opening/closing forces for all files in list' 'Pulling'})
ylabel('Count')

subplot(2,1,2)
hist(xy(i_relaxes_closed,2))
title('Relaxing')
xlabel('Force (pN)')
ylabel('Count')
a2 = gca;

figure

fpullopen = xy(i_pulls_open,2);
frelaxclosed = xy(i_relaxes_closed,2);

%the two lists aren't the same length, and to use hist with both in a simple
%way, have to have them in the same matrix. Make a matrix big enough for
%the longest, make NaN to start (won't be used by hist).
lp = length(fpullopen);
lr = length(frelaxclosed);

both = zeros(max([lp lr]),2)*NaN;
both(1:lp,1) = fpullopen;
both(1:lr,2) = frelaxclosed;

hist(both)

title('Tether opening/closing forces for all files in list')
ylabel('Count')
xlabel('Force (pN)')
legend({'Pulling/opening' 'Relaxing/closing'})
% [binp hp] = hist(fpullopen);
% [binr hr] = hist(frelaxclosed);


% both = [xy(i_pulls_open,2) xy(i_relaxes_closed,2)]
% hist(both)
% 
% bar

figure

extpullopen = delta_ext(i_pulls_open);
extrelaxclosed = delta_ext(i_relaxes_closed);

both(1:lp,1) = extpullopen;
both(1:lr,2) = extrelaxclosed;

hist(both)

title('Tether opening/closing change in extension for all files in list')
ylabel('Count')
xlabel('\Delta Ext (nm)')
legend({'Pulling/opening' 'Relaxing/closing'})





