function set_contextmenu_fext(hlines)
%create context menu (right click menu) for all f-ext traces
%Can run this at any time a figure is the active (current) figure (e.g.,
%after making a new f-ext, after opening an already made f-ext

%Modified so this same function can be run independently (to apply to an
%old file - it finds the lines) or at the time of creation of the f-ext
%plot.

%140403 mjc

%% Define context menu for individual f-ext traces; it is not attached to anything
% Locate line objects

if nargin == 0
    %running on an old figure, find the lines
    global nfittraces
    if isempty(nfittraces)
        nfittraces = 1;
    end
    hlines = findall(gca,'Type','line');
    hlines = flipud(hlines(1+nfittraces:end));%get rid of fits, and flip upside down to get in proper order
    ud.ntraces = length(hlines);%save this to figure
    ud.nfittraces = nfittraces;
    ud.hlines = hlines;
    ud.trace_offsets = zeros(ud.ntraces,1);
    set(gcf,'userd',ud);
else
    ud = get(gcf,'userd');
end

hcmenu = uicontextmenu;

% Define callbacks for context menu (a string), then install

%menu item 1
cbstring = 'Add events manually';
hcb = @add_f_ext_pairs_cb;
item = uimenu(hcmenu,'Label',cbstring,'Callback',hcb);

%menu item 2
cbstring = 'Remove events manually';
hcb = @remove_f_ext_pairs_cb;
item = uimenu(hcmenu,'Label',cbstring,'Callback',hcb);

% Attach the context menu to each line
% Also tag each line with trace # (for changing visibility)
for line = 1:ud.ntraces
    set(hlines(line),'uicontextmenu',hcmenu);
    set(hlines(line),'tag',['trace' num2str(line)]);
end

%% Define context menu for the axis (background)
% being separate from the lines menu makes it less likely to click by
% accident
hcmenu_fig = uicontextmenu;

% Define callbacks for context menu (a string), then install

%global list should be called: 'f_ext_analysis_global_list'

%menu item
cbstring = 'Show fit interval';
hcb = @show_fit_interval_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb,'checked','off');

%menu item
cbstring = 'Separate traces';
hcb = @separate_traces_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb,'separator','on');

%menu item
cbstring = 'Combine traces';
hcb = @combine_traces_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb);

%menu item
cbstring = 'Find opening/closing events in traces';
hcb = @find_open_close_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb,'separator','on');

%menu item
cbstring = 'Delete all events';
hcb = @delete_all_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb);

%menu item
cbstring = 'Add file''s events to global list';
hcb = @add_all_events_global_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb,'separator','on');

%menu item
cbstring = 'Remove file''s events from global list';
hcb = @remove_all_events_global_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb);

%menu item
cbstring = 'List files in global list';
hcb = @list_files_in_global_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb);

%menu item
cbstring = 'Plot histograms of opening/closing events for all files';
hcb = @hist_open_close_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb,'separator','on');

%add a menu item for each line, to check on/off visibility of it and the
%associated markers

%first add choice to turn all lines on/off

%menu item 4
cbstring = 'All lines off';
hcb = @all_lines_off_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb,'separator','on');

%menu item 5
cbstring = 'All lines visible';
hcb = @all_lines_vis_cb;
item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb);

colors = lines(ud.ntraces);
for i = 1:ud.ntraces
    cbstring = ['Trace ' num2str(i)];
    %is it visible now?
    chstr = get(hlines(i),'visible');
    hcb = @trace_vis_cb;
    
    item = uimenu(hcmenu_fig,'Label',cbstring,'Callback',hcb,'Tag',['trace' num2str(i)],'checked',chstr,'ForegroundColor',colors(i,:));
end

% Attach the context menu to the axis
set(gca,'uicontextmenu',hcmenu_fig)

