function x = XFJCContour(F, P, S, kT, option)
% x = XWLCContour(F, P, S, kT, option)
%
% Calculates extension over contour x/L given force F (pN), 
% persistence length P (nm) and stretch modulus S (pN).
%
% If option = 1 returns extension over contour x/L;
% if option = 2 returns stiffness times contour KL.

% Default Values
if nargin < 4
    kT = 4.14;
end
if nargin < 3
    S = 800;
end
if nargin < 2
    P = 0.75;
end

if F == 0
    x = 0;
else     
    x = (coth(2*F*P/kT) - kT./(2*F*P)).*(1+F/S);
end;

if nargin == 5 & option >= 1 %return dKL/dx
    w1 = -(csch(2*F*P/kT)).^2 + (kT./(2*F*P)).^2;
    w2 = coth(2*F*P/kT) - kT./(2*F*P);
    k = 1./(w1*2*P/kT.*(1+F/S) + w2/S);
    if option == 1
        x = k;
    end;
    if option == 2
     %   x = dkdx;
    end;    
end; 