function data = trapraster(data,cal,fakeoffset,offset)
%function to analyze raster scan data of one plot and return analyzed data%
%100303 mjc

% fakeoffset = 0;%offset that can be added to bead separation (i.e., wrong bead size), 91 before
step_offset = 0;

%AOD calibration
global XAODcal;
global YAODcal;

% XAODcal = 790;%conversion multiplier, (nm/MHz), lab book 3 page 8
% YAODcal = 840;%conversion multiplier, (nm/MHz)
% XAODcal = 151.5;%AOM #2 conversion multiplier, (nm/MHz), lab book 3 page 46, 123
% YAODcal = 0;%conversion multiplier, (nm/MHz), there is no y motion though with AOM
XAODcenter = 80;%(MHz), not important, just defines the origin of my coordinate axes, for plotting purposes
YAODcenter = 26;%

%separate out the single time traces to individual scans (backwards scans
%are flipped
data = separate_raster_data(data);

N = data.nscanfb * 2;%total number of scans (forward + backward)

%when doing the raster scan, should not subtract the offset if subtracting
%the position offset or will double subtract the cal offset!

%calibrate data
if nargin > 3 && ~isempty(offset) %subtract position offset scan
    axoffraw = offset.axoffraw;
    ayoffraw = offset.ayoffraw;
    bxoffraw = offset.bxoffraw;
    byoffraw = offset.byoffraw;    
    
    %use interpolation in case that the frequency values of the
    %raster scan do not match those of the offset
    intmethod = 'linear';
    axoffi = interp1(offset.nu,axoffraw,data.nu,intmethod);
    ayoffi = interp1(offset.nu,ayoffraw,data.nu,intmethod);
    bxoffi = interp1(offset.nu,bxoffraw,data.nu,intmethod);
    byoffi = interp1(offset.nu,byoffraw,data.nu,intmethod);
        
    if step_offset == 1 %frequency steps
        %now take means of each frequency step
        axoffm = mean(reshape(axoffi,data.samples_scan/data.nsteps,[]));
        ayoffm = mean(reshape(ayoffi,data.samples_scan/data.nsteps,[]));
        bxoffm = mean(reshape(bxoffi,data.samples_scan/data.nsteps,[]));
        byoffm = mean(reshape(byoffi,data.samples_scan/data.nsteps,[]));
        
        %expand array to fill data points
        axoffrep = repmat(axoffm,[data.samples_scan/data.nsteps,1]);
        ayoffrep = repmat(ayoffm,[data.samples_scan/data.nsteps,1]);
        bxoffrep = repmat(bxoffm,[data.samples_scan/data.nsteps,1]);
        byoffrep = repmat(byoffm,[data.samples_scan/data.nsteps,1]);
        
        axoff = reshape(axoffrep,1,[]);
        ayoff = reshape(ayoffrep,1,[]);
        bxoff = reshape(bxoffrep,1,[]);
        byoff = reshape(byoffrep,1,[]);
        
        if 1 %check offset calc
            figure('Position',[255         124        1022         781])
            subplot(2,2,1)
            plot(offsetdata.nu,axoffraw,data.nu,axoffi,'r',data.nu,axoff,'k');
            ylabel('AX Offset(nm)')
            legend({'Raw Offset' 'Interpolated' 'Averaged Per Step'})
            title('Trap 1 (moving)');
            subplot(2,2,2)
            plot(offsetdata.nu,bxoffraw,data.nu,bxoffi,'r',data.nu,bxoff,'k');
            ylabel('BX Offset(nm)')
            title('Trap 2 (fixed)')
            subplot(2,2,3)
            plot(offsetdata.nu,ayoffraw,data.nu,ayoffi,'r',data.nu,ayoff,'k');
            ylabel('AY Offset(nm)')
            xlabel('Frequency (MHz)');
            subplot(2,2,4)
            plot(offsetdata.nu,byoffraw,data.nu,byoffi,'r',data.nu,byoff,'k');
            ylabel('BY Offset(nm)')
            xlabel('Frequency (MHz)');
            
        end
    else
        axoff = axoffi;
        ayoff = ayoffi;
        bxoff = bxoffi;
        byoff = byoffi;
    end
        
    %replicate for subtraction
    axoffrep = repmat(axoff,[N,1]);
    ayoffrep = repmat(ayoff,[N,1]);
    bxoffrep = repmat(bxoff,[N,1]);
    byoffrep = repmat(byoff,[N,1]);
    
    %create calibrated position data
    data.A_Xcal = (data.A_X-axoffrep)*cal.alphaAX;
    data.A_Ycal = (data.A_Y-ayoffrep)*cal.alphaAY;
    data.B_Xcal = (data.B_X-bxoffrep)*cal.alphaBX;
    data.B_Ycal = (data.B_Y-byoffrep)*cal.alphaBY;
        
else  %no offset subtract
    data.A_Xcal = (data.A_X-cal.AXoffset)*cal.alphaAX;
    data.A_Ycal = (data.A_Y-cal.AYoffset)*cal.alphaAY;
    data.B_Xcal = (data.B_X-cal.BXoffset)*cal.alphaBX;
    data.B_Ycal = (data.B_Y-cal.BYoffset)*cal.alphaBY;
end

%create force data
data.A_FX = data.A_Xcal*cal.kappaAX;
data.A_FY = data.A_Ycal*cal.kappaAY;
data.B_FX = data.B_Xcal*cal.kappaBX;
data.B_FY = data.B_Ycal*cal.kappaBY;

%create bead separation data

%fixed trap bead position, add trap position (a constant) to bead position
data.B_Xabs = data.B_Xcal + (data.t2x-XAODcenter)*XAODcal;
data.B_Yabs = data.B_Ycal + (data.t2y-YAODcenter)*YAODcal;

%create moving bead position

%negative going bead position means moving to the right in X
%negative going bead position means moving up in Y
if data.scandir == 1
    data.t1xpos = (data.t1x + data.nu - XAODcenter)*XAODcal;
    data.t1ypos = (data.t1y + zeros(1,data.samples_scan) - YAODcenter)*YAODcal;
else
    data.t1ypos = (data.t1y + data.nu - YAODcenter)*YAODcal;
    data.t1xpos = (data.t1x + zeros(1,data.samples_scan) - XAODcenter)*XAODcal;
end

data.t1xposrep = repmat(data.t1xpos,[N,1]);
data.t1yposrep = repmat(data.t1ypos,[N,1]);

data.A_Xabs = data.A_Xcal + data.t1xposrep;
data.A_Yabs = data.A_Ycal + data.t1yposrep;

data.beadsep = sqrt((data.A_Xabs - data.B_Xabs).^2 + (data.A_Yabs - data.B_Yabs).^2) - cal.beadA/2 - cal.beadB/2 + fakeoffset;

end

