function plot_fluor_time_series(param)
%plot just the fluorescence data vs time for APD 1
global fbslash %/ or \
global datadirectories
global fltestdir
global figdirbottom
global laptop
global beaddiameters

figdirbottom = ['UvrD' fbslash 'UvrD-Cy3' fbslash];

%% parameters
if nargin == 0
    Date = '131024';
    calfilenumber =   29;
    offsetfilenumber =  [];
    datafilenumber = 31;

    xlimits = [];
    extbackgndint = [0 10];

    bdiameters = [];
else
    Date = param.Date;
    calfilenumber = param.calfilenumber;
    offsetfilenumber = param.offsetfilenumber;
    datafilenumber = param.datafilenumber;
    
    xlimits = param.xlimits;
    extbackgndint = param.extbackgndint;
    bdiameters = param.beaddiameters;
end


Savefigdir = [fltestdir figdirbottom Date fbslash 'figs' fbslash];

subtract_ext_back = 1;
subtract_fl_back = 0;

flbackgndint = [];

calibrate = 1;

plot_force = 1;
plot_ext = 0;
plot_fluor = 0;
plot_FRET = 0;
is_raster = 0;
plot_pos = 0;

% trap downsampling bandwidth
desired_trap_bw = 233;

% fluorescence integration
integration = 1;

fakeoffset = 0;

forcecal = 0;%even if cal already done and stored

if isempty(calfilenumber)
    plot_force = 0;
end

if isempty(flbackgndint)
    flbackgndint = extbackgndint;
end


%% get data
nplots = plot_force + plot_ext + plot_fluor + plot_FRET + plot_pos;

startpath = [datadirectories Date fbslash];

% need to get calibration data
if plot_force || plot_ext
    
    if isempty(offsetfilenumber) && is_raster == 1
        offsetfilenumber = calfilenumber + 1;
    end
    
    if isempty(datafilenumber)
        datafilenumber = calfilenumber + 2;
    end
    
    calrootfile = [Date '_' num2str(calfilenumber,'%03d') '.dat'];
    calfilename = ['cal' calrootfile(1:(end-4))];
    fitfilename = ['fit' calrootfile(1:(end-4))];

end

rootfile = [Date '_' num2str(datafilenumber,'%03d') '.dat'];
datafilename = ['data_' rootfile(1:(end-4))];

%% get data
data1 = ReadMattFile_Wrapper(startpath,rootfile);

% data1 = readheaders(data1)

%% get calibration
if plot_force || plot_ext
    eval(['global ' calfilename]);
    
    calexist = evalin('base',['exist(''' calfilename ''')']);
    
    if ~calexist || forcecal%then do calibration
        
        if ~isempty(bdiameters)
            old = beaddiameters;
            beaddiameters = bdiameters
        end
        tic
        CalibrateStrippedWrapper(Date,calrootfile);
        toc
        if ~isempty(bdiameters)
            beaddiameters = old;
        end
        
        cal = evalin('base',calfilename);
        fit = evalin('base',fitfilename);
        
    else
        cal = evalin('base',calfilename);
        fit = evalin('base',fitfilename);
    end
end



%% remove offset from a raster scan
if plot_force && is_raster
    %get offset data
    if ~isempty(offsetfilenumber) %if use offset file
        offsetrootfile = [Date '_' num2str(offsetfilenumber,'%03d') '.dat'];
        offsetdata = ReadMattFile_Wrapper(startpath,offsetrootfile);
        offsetdata = separate_raster_data(offsetdata);
        %take mean of multiple scans (uncalibrated)
        offset.axoffraw = mean(offsetdata.A_X);
        offset.ayoffraw = mean(offsetdata.A_Y);
        offset.bxoffraw = mean(offsetdata.B_X);
        offset.byoffraw = mean(offsetdata.B_Y);
        offset.nu = offsetdata.nu;
        
        data = trapraster(data1,cal,fakeoffset,offset);
    else %don't use offset file
        data = trapraster(data1,cal,fakeoffset);
    end
else
    data = data1;
end

TrapAveFactor = round((1/data.sampperiod)/desired_trap_bw);

t = downsample(data.time,TrapAveFactor);

if calibrate
    
AXcal = (data.A_X-cal.AXoffset)*cal.alphaAX;
BXcal = (data.B_X-cal.BXoffset)*cal.alphaBX;
PDiff = BXcal - AXcal;

AXcal = downsample(AXcal,TrapAveFactor);
BXcal = downsample(BXcal,TrapAveFactor);

AXforce = AXcal * cal.kappaAX;
BXforce = BXcal * cal.kappaBX;

PDiff = downsample(PDiff,TrapAveFactor);

else
    PDiff = data.B_X - data.A_X;

end

data.apd1 = apd_integrate(data.apd1,integration);
data.apd2 = apd_integrate(data.apd2,integration);
data.apdtime = downsample(data.apdtime,integration);

%subinterval indices to take ext means for subtraction
if subtract_ext_back
    if isempty(extbackgndint)
        extbackgndint = [2 3];
    end
    [m m1] = min(abs(t - extbackgndint(1)));
    [m m2] = min(abs(t - extbackgndint(2)));
    mint = m1:m2;%mean interval indices

    PDiff = PDiff - mean(PDiff(mint));
end

%subinterval indices to take fl means for subtraction
if subtract_fl_back && ~isempty(flbackgndint)
    [m m1] = min(abs(data.apdtime - flbackgndint(1)));
    [m m2] = min(abs(data.apdtime - flbackgndint(2)));
    mint = m1:m2;%mean interval indices

    data.apd1 = data.apd1 - mean(data.apd1(mint));
    data.apd2 = data.apd2 - mean(data.apd2(mint));
end

tfactor = 1/(data.apdtime(2)-data.apdtime(1));

if nplots == 1
    hfig = figure('Position',[53         450        1651         496]);
else
    %good for MB Air
    hfig = figure('Position',[14 55+250*(3-nplots) 1400 floor(800/3*nplots)]);
end

set(gcf,'FileName',[Savefigdir Date '_' num2str(datafilenumber,'%03d')]);
set(gcf,'Name',[Date '_' num2str(datafilenumber,'%03d') ' APD 1 Counts']);

ploti = 0;
axeshandles = [];

%plot delta extension
if plot_ext
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    axeshandles = [axeshandles gca];
    
    plot(t,PDiff)
    
    ylabel('\DeltaExtension (nm)')
end    

%plot force
if plot_force
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    axeshandles = [axeshandles gca];

    if is_raster
        meanf = (abs(data.A_FX)+abs(data.B_FX))/2;
        [r c] = size(meanf);
        %need to reverse the even traces (they are the relaxations, were
        %flipped to plot vs. ext)
        for jj = (1:(r/2))*2
            meanf(jj,:) = fliplr(meanf(jj,:));
        end
        meanflin = reshape(meanf',[],1);
        t = ((1:(c*r))-1)*(data.t(2)-data.t(1));
        plot(t',meanflin);
        axis tight
        ylim([0 15])
    else
        plot(t,AXforce,'b')
        hold on
        plot(t,-BXforce,'r')
        plot(t,(AXforce-BXforce)/2,'k','linewidth',2)
        legend({'Trap 1','Trap 2','Mean'})
        ylim([0 15])
    end
    
    ylabel('Force (pN)')
end

%plot fluorescence
if plot_fluor
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    plot(data.apdtime,tfactor/1e3*data.apd1,'g','LineWidth',1)
    hold on
    plot(data.apdtime,tfactor/1e3*data.apd2,'r','LineWidth',1)
    axis tight
    axeshandles = [axeshandles gca];
    ylabel('Photon Rate (kHz)')
    legend({'APD1 (Cy3)' 'APD2 (Cy5)'})
end

%plot FRET
if plot_FRET
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    FRET = data.apd2./(data.apd1 + data.apd2);
    plot(data.apdtime,FRET,'b','LineWidth',1)
    ylabel('FRET Efficiency')
    axis tight
    ylim([-0.25 1.25])
    axeshandles = [axeshandles gca];
    
end

%plot just positions, uncalibrated
if plot_pos
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    plot(data.time,data.A_X,'b','LineWidth',1)
    hold on 
    plot(data.time,data.B_X,'k','LineWidth',1)
    plot(data.time,data.A_Y,'r','LineWidth',1)
    plot(data.time,data.B_Y,'g','LineWidth',1)
    
    legend({'AX' 'BX' 'AY' 'BY'})
    ylabel('Raw trap signal (V)')
    axis tight
    axeshandles = [axeshandles gca];
    title('Raw trap measurements')
end

xlabel('Time (s)')

axes(axeshandles(1))
title(['Raw trap measurements (' Date '\_' num2str(datafilenumber,'%03d') ')'])

linkaxes(axeshandles,'x')

if ~isempty(xlimits)
    xlim(xlimits)
end

if exist('param')
    set(gcf,'userData',param);
end

assignin('base',datafilename,data);
