function plot_trap_sum_time_series(param)
%plot just the fluorescence data vs time for APD 1
global fbslash %/ or \
global datadirectories
global fltestdir
global figdirbottom
global laptop
global beaddiameters

figdirbottom = ['UvrD' fbslash 'UvrD-Cy3' fbslash];

%% parameters
if nargin == 0
    Date = '140204';
    calfilenumber =  24   ;
    offsetfilenumber =  [];
    datafilenumber = 30;
    
    xlimits = [];
    extbackgndint = [];
    
    bdiameters = [];
else
    Date = param.Date;
    calfilenumber = param.calfilenumber;
    offsetfilenumber = param.offsetfilenumber;
    datafilenumber = param.datafilenumber;
    
    xlimits = param.xlimits;
    extbackgndint = param.extbackgndint;
    bdiameters = param.beaddiameters;
end


Savefigdir = [fltestdir figdirbottom Date fbslash 'figs' fbslash];

subtract_ext_back = 1;
subtract_fl_back = 0;

flbackgndint = [];

plot_qpdsum = 1;
plot_qpdx = 0;
plot_force = 0;
plot_ext = 0;
plot_fluor = 0;
plot_FRET = 0;
is_raster = 0;

%if true, will force a calibration
do_cal = 1;

% trap downsampling bandwidth
desired_trap_bw = 10;

% fluorescence integration
integration = 20; %default 20

fakeoffset = 0;

forcecal = 0;%even if cal already done and stored

if isempty(calfilenumber)
    calibrated = 0;
    plot_force = 0;
else
    calibrated = 1;
end

calibrated 

if isempty(flbackgndint)
    flbackgndint = extbackgndint;
end


%% get data
nplots = plot_qpdsum + plot_qpdx + plot_force + plot_ext + plot_fluor + plot_FRET;

startpath = [datadirectories Date fbslash];

% if need to get calibration data
if plot_force || plot_ext || do_cal
    
    if isempty(offsetfilenumber) && is_raster == 1
        offsetfilenumber = calfilenumber + 1;
    end
    
    if isempty(datafilenumber)
        datafilenumber = calfilenumber + 2;
    end
    
    calrootfile = [Date '_' num2str(calfilenumber,'%03d') '.dat'];
    calfilename = ['cal' calrootfile(1:(end-4))];
    fitfilename = ['fit' calrootfile(1:(end-4))];
    
end

rootfile = [Date '_' num2str(datafilenumber,'%03d') '.dat'];
datafilename = ['data_' rootfile(1:(end-4))];

%% get data
data1 = ReadMattFile_Wrapper(startpath,rootfile);

%% get calibration
if plot_force || plot_ext || do_cal
    eval(['global ' calfilename]);
    
    calexist = evalin('base',['exist(''' calfilename ''')']);
    
    if ~calexist || forcecal%then do calibration
        
        if ~isempty(bdiameters)
            old = beaddiameters;
            beaddiameters = bdiameters
        end
        tic
        CalibrateStrippedWrapper(Date,calrootfile);
        toc
        if ~isempty(bdiameters)
            beaddiameters = old;
        end
        
        cal = evalin('base',calfilename);
        fit = evalin('base',fitfilename);
        
    else
        cal = evalin('base',calfilename);
        fit = evalin('base',fitfilename);
    end
end



%% remove offset from a raster scan
if plot_force && is_raster
    %get offset data
    if ~isempty(offsetfilenumber) %if use offset file
        offsetrootfile = [Date '_' num2str(offsetfilenumber,'%03d') '.dat'];
        offsetdata = ReadMattFile_Wrapper(startpath,offsetrootfile);
        offsetdata = separate_raster_data(offsetdata);
        %take mean of multiple scans (uncalibrated)
        offset.axoffraw = mean(offsetdata.A_X);
        offset.ayoffraw = mean(offsetdata.A_Y);
        offset.bxoffraw = mean(offsetdata.B_X);
        offset.byoffraw = mean(offsetdata.B_Y);
        offset.nu = offsetdata.nu;
        
        data = trapraster(data1,cal,fakeoffset,offset);
    else %don't use offset file
        data = trapraster(data1,cal,fakeoffset);
    end
else
    data = data1;
end

TrapAveFactor = round((1/data.sampperiod)/desired_trap_bw);

t = downsample(data.time,TrapAveFactor);

if calibrated
    AXcal = (data.A_X-cal.AXoffset)*cal.alphaAX;
    BXcal = (data.B_X-cal.BXoffset)*cal.alphaBX;
    PDiff = BXcal - AXcal;
    
    AXcal = downsample(AXcal,TrapAveFactor);
    BXcal = downsample(BXcal,TrapAveFactor);
    
    AXforce = AXcal * cal.kappaAX;
    BXforce = BXcal * cal.kappaBX;
    
    PDiff = downsample(PDiff,TrapAveFactor);
end

data.apd1 = apd_integrate(data.apd1,integration);
data.apd2 = apd_integrate(data.apd2,integration);
data.apdtime = downsample(data.apdtime,integration);

%subinterval indices to take ext means for subtraction
if subtract_ext_back
    if isempty(extbackgndint)
        extbackgndint = [2 3];
    end
    [m m1] = min(abs(t - extbackgndint(1)));
    [m m2] = min(abs(t - extbackgndint(2)));
    mint = m1:m2;%mean interval indices

    if calibrated
        PDiff = PDiff - mean(PDiff(mint));
    end
end

%subinterval indices to take fl means for subtraction
if subtract_fl_back && ~isempty(flbackgndint)
    [m m1] = min(abs(data.apdtime - flbackgndint(1)));
    [m m2] = min(abs(data.apdtime - flbackgndint(2)));
    mint = m1:m2;%mean interval indices
    
    data.apd1 = data.apd1 - mean(data.apd1(mint));
    data.apd2 = data.apd2 - mean(data.apd2(mint));
end

tfactor = 1/(data.apdtime(2)-data.apdtime(1));

if nplots == 1
    hfig = figure('Position',[53         450        1651         496]);
else
    %good for MB Air
    hfig = figure('Position',[14 55+250*(3-nplots) 1400 floor(800/3*nplots)]);
end

set(gcf,'FileName',[Savefigdir Date '_' num2str(datafilenumber,'%03d')]);
set(gcf,'Name',[Date '_' num2str(datafilenumber,'%03d') ' APD 1 Counts']);

ploti = 0;
axeshandles = [];

%plot delta extension
if plot_ext
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    axeshandles = [axeshandles gca];
    plot(t,PDiff,'k')
    ylabel('\DeltaExtension (nm)')
    %ylim([-70 -67])
end

%plot force
if plot_force & 0
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    axeshandles = [axeshandles gca];
    
    if is_raster
        meanf = (abs(data.A_FX)+abs(data.B_FX))/2;
        [r c] = size(meanf);
        %need to reverse the even traces (they are the relaxations, were
        %flipped to plot vs. ext)
        for jj = (1:(r/2))*2
            meanf(jj,:) = fliplr(meanf(jj,:));
        end
        meanflin = reshape(meanf',[],1);
        t = ((1:(c*r))-1)*(data.t(2)-data.t(1));
        plot(t',meanflin);
        axis tight
        ylim([0 15])
    else
        plot(t,AXforce,'b')
        hold on
        plot(t,-BXforce,'r')
        plot(t,(AXforce-BXforce)/2,'k','linewidth',2)
        legend({'Trap 1','Trap 2','Mean'})
        %ylim([8 15])
    end
    
    ylabel('Force (pN)')
end

%plot fluorescence
if plot_fluor
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    plot(data.apdtime,tfactor/1e3*data.apd1,'g','LineWidth',1.5)
    hold on
    plot(data.apdtime,tfactor/1e3*data.apd2,'r','LineWidth',1.5)
    hold on
%    plot(data.apdtime,tfactor/1e3*data.apd3,'b','LineWidth',1.5)
    axis tight
    axeshandles = [axeshandles gca];
    ylabel('Photon Rate (kHz)')
    legend({'APD1 (Cy3)' 'APD2 (Cy5)' 'APD3 (Cy2)'})
%      ylim([20 37])
end

%plot FRET
if plot_FRET
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    FRET = data.apd2./(data.apd1 + data.apd2);
    plot(data.apdtime,FRET,'b','LineWidth',1)
    ylabel('FRET Efficiency')
    axis tight
    ylim([-0.25 1.25])
    axeshandles = [axeshandles gca];
    
end

%plot trap qpd sum
if plot_qpdsum
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    
    intensity_mean = mean(data.A_Sum);
    intensity_mean = 1;
    plot(data.time,data.A_Sum/intensity_mean);
    hold on
%     plot(data.time,data.A_FB_Sum/mean(data.A_FB_Sum),'k');
    plot(data.time,data.A_FB_Sum,'k');
    title('Trap QPD Sum (Total light intensity)')
    ylabel('QPD Sum (V)')
    legend({'Trap QPD A\_Sum' 'FB QPD A\_Sum'}) 
    axeshandles = [axeshandles gca];
end

if plot_qpdx
    ploti = ploti + 1;
    subplot(nplots,1,ploti)
    
    intensity_mean = mean(data.A_Sum);
    plot(data.time,data.A_X/intensity_mean);
    hold on
    plot(data.time,data.A_X,'k');
    title('Trap QPD X')
    ylabel('QPD X')
    legend({'Trap QPD A\_X norm' 'Trap QPD A\_X'}) 
    axeshandles = [axeshandles gca];
end
xlabel('Time (s)')

axes(axeshandles(1))
title(['AOM wiggle testing (' Date '\_' num2str(datafilenumber,'%03d') ')'])

linkaxes(axeshandles,'x')

if ~isempty(xlimits)
    xlim(xlimits)
end

if exist('param')
    set(gcf,'userData',param);
end

assignin('base',datafilename,data);
